@@ -172,14 +172,12 @@ class ModelServer:
             try:
                 keys = list(inputs[0].keys())
                 sizes = [sample_inputs[keys[0]].shape[0] for sample_inputs in inputs]
-                start_time = time.time()
                 inputs = {
                     key: self.pad_and_concat(list(map(itemgetter(key), inputs)), pad_map.get(key, 0))
                     for key in keys
                 }
                 with torch.no_grad():
                     outputs = self.model.forward(**inputs)
-                logger.debug(f'MODEL SPENT {time.time() - start_time} on bsz {sum(sizes)}')
                 for session_state, output in zip(session_states, self.split_output(outputs, sizes)):
                     session_state.send_output(output)
             except Exception as e:
